@@ -40,7 +40,7 @@ class instrument:  # Instantiated as SN
     #         dev[0].set_configuration()
     #         self.spec = sn.find_devices([0])
     # =============================================================================
-    def __init__(self):
+    def __init__(self,port):
         '''Initialization:
             finds spectrometer'''
         # dev = usb.core.find(find_all=True) ##seems to fix
